@@ -618,7 +618,7 @@ def step_(*args):
 
     return "(0 if t < " + str(time) + " else " + str(height) + ")"
 
-def savediv_(*args):
+def safediv_(*args):
     args = remove_nesting(args)
 
     nominator = parseExpression(args[0])
@@ -626,10 +626,10 @@ def savediv_(*args):
     onzero = None if len(args) ==2 else parseExpression(args[2])
 
     if onzero is not None:
-        return "( "+ str(onzero) + ")" + ' if (' + str(denominator) + ') == 0 else (' + str(nominator) + ' / ' + str(denominator) + ")"
+        return "(( "+ str(onzero) + ")" + ' if (' + str(denominator) + ') == 0 else (' + str(nominator) + ' / ' + str(denominator) + "))"
     else:
-        return "(0)" + ' if (' + str(denominator) + ') == 0 else (' + str(nominator) + ' / ' + str(
-            denominator) + ")"
+        return "((0)" + ' if (' + str(denominator) + ') == 0 else (' + str(nominator) + ' / ' + str(
+            denominator) + "))"
 
 def history_(*args):
     args = remove_nesting(args)
@@ -877,9 +877,7 @@ builtins = {
 
     'arctan': lambda body: 'np.arctan(' + parseExpression(body) + ')',
 
-    'savediv': lambda *args: savediv_(args),
-
-    'safediv': lambda *args: savediv_(args),
+    'safediv': lambda *args: safediv_(args),
 
     'step': lambda *args: step_(args),
 
